==> cloudt-boot-starter-threadpool-3.2.4.1-20230517.080508-1-sources.jar: com/elitescloud/boot/threadpool/support/CustomTaskExecutor.java <==
package com.elitescloud.boot.threadpool.support;

import cn.hutool.core.text.CharSequenceUtil;
import com.dtp.common.config.DtpProperties;
import com.dtp.common.config.ThreadPoolProperties;
import com.dtp.core.DtpRegistry;
import com.dtp.core.thread.DtpExecutor;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.util.CollectionUtils;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 自定义TaskExecutor.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/20
 */
public class CustomTaskExecutor extends ThreadPoolTaskExecutor {
    private static final long serialVersionUID = -669239293574082521L;

    public static final String CLOUDT_DTP_DEFAULT = "cloudT-dtp-default";
    public static final String CLOUDT_TP = "cloudT-tp-";

    private DtpExecutor dtpExecutor;

    public CustomTaskExecutor(DtpProperties dtpProperties) {
        buildDtpExecutor(dtpProperties);
    }

    @Override
    public void execute(@NonNull Runnable task) {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        dtpExecutor.execute(task);
    }

    @NonNull
    @Override
    protected ExecutorService initializeExecutor(@NonNull ThreadFactory threadFactory, @NonNull RejectedExecutionHandler rejectedExecutionHandler) {
        if (dtpExecutor == null) {
            if (DtpRegistry.listAllDtpNames().contains(CLOUDT_DTP_DEFAULT)) {
                dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
            } else {
                dtpExecutor = this.createDefault();
            }
        }

        return dtpExecutor;
    }

    @Override
    public ThreadPoolExecutor getThreadPoolExecutor() throws IllegalStateException {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        return dtpExecutor;
    }

    private void buildDtpExecutor(DtpProperties dtpProperties) {
        var executorsConfigs = dtpProperties.getExecutors();
        if (dtpProperties.isEnabled() && !CollectionUtils.isEmpty(executorsConfigs)) {
            for (ThreadPoolProperties executorsConfig : executorsConfigs) {
                if (CharSequenceUtil.equals(executorsConfig.getThreadPoolName(), CLOUDT_DTP_DEFAULT)) {
                    // 已存在相关配置，则DtpRegistry.afterPropertiesSet()会自动创建，无需手动创建
                    return;
                }
            }
        }

        // 构建默认的dtpExecutor
        this.createDefault();
    }

    private DtpExecutor createDefault() {
        return (DtpExecutor) ThreadPoolHolder.createThreadPool(CLOUDT_DTP_DEFAULT, CLOUDT_TP, 8, 17);
    }
}

==> cloudt-boot-starter-threadpool-3.2.4.28-20230615.121938-2-sources.jar: com/elitescloud/boot/threadpool/support/CustomTaskExecutor.java <==
package com.elitescloud.boot.threadpool.support;

import cn.hutool.core.text.CharSequenceUtil;
import com.dtp.common.config.DtpProperties;
import com.dtp.common.config.ThreadPoolProperties;
import com.dtp.core.DtpRegistry;
import com.dtp.core.thread.DtpExecutor;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.util.CollectionUtils;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 自定义TaskExecutor.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/20
 */
public class CustomTaskExecutor extends ThreadPoolTaskExecutor {
    private static final Logger LOG = LoggerFactory.getLogger(CustomTaskExecutor.class);
    private static final long serialVersionUID = -669239293574082521L;

    public static final String CLOUDT_DTP_DEFAULT = "cloudT-dtp-default";
    public static final String CLOUDT_TP = "cloudT-tp-";

    private DtpExecutor dtpExecutor;

    public CustomTaskExecutor(DtpProperties dtpProperties) {
        buildDtpExecutor(dtpProperties);
    }

    @Override
    public void execute(@NonNull Runnable task) {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        dtpExecutor.execute(task);
    }

    @NonNull
    @Override
    protected ExecutorService initializeExecutor(@NonNull ThreadFactory threadFactory, @NonNull RejectedExecutionHandler rejectedExecutionHandler) {
        if (dtpExecutor == null) {
            if (DtpRegistry.listAllDtpNames().contains(CLOUDT_DTP_DEFAULT)) {
                dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
            } else {
                dtpExecutor = this.createDefault();
            }
        }

        return dtpExecutor;
    }

    @Override
    public ThreadPoolExecutor getThreadPoolExecutor() throws IllegalStateException {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        return dtpExecutor;
    }

    private void buildDtpExecutor(DtpProperties dtpProperties) {
        var executorsConfigs = dtpProperties.getExecutors();
        if (dtpProperties.isEnabled() && !CollectionUtils.isEmpty(executorsConfigs)) {
            for (ThreadPoolProperties executorsConfig : executorsConfigs) {
                if (CharSequenceUtil.equals(executorsConfig.getThreadPoolName(), CLOUDT_DTP_DEFAULT)) {
                    // 已存在相关配置，则DtpRegistry.afterPropertiesSet()会自动创建，无需手动创建
                    LOG.info("ThreadPool Config will use config center");
                    return;
                }
            }
        }

        // 构建默认的dtpExecutor
        this.createDefault();
    }

    private DtpExecutor createDefault() {
        LOG.info("ThreadPool Config will use default");
        return (DtpExecutor) ThreadPoolHolder.createThreadPool(CLOUDT_DTP_DEFAULT, CLOUDT_TP, 8, 17);
    }
}
